@@ -71,7 +71,7 @@ class Pararamio:
             self._cookie.save(ignore_discard=True)
 
     def _profile(self, raise_on_error: bool = False) -> 'ProfileTypeT':
-        return self.api_get('/user/profile', raise_on_error=raise_on_error).get('message', {})
+        return self.api_get('/user/me', raise_on_error=raise_on_error)
 
     def _do_auth(self, login: str, password: str, cookie_jar: CookieJar, headers: Dict[str, str], second_step_fn: SecondStepFnT,
                  second_step_arg: str, ) -> None:
@@ -202,18 +202,19 @@ class Pararamio:
             ('quote_range', quote_range)
         ]
         with open(file_path, 'rb') as f:
-            return xupload_file(fp=f, fields=fields, headers=self.__headers, cookie_jar=self._cookie)
+            return xupload_file(fp=f, fields=fields, headers=self.__headers, cookie_jar=self._cookie), dict(fields)
 
     def direct_upload_file(self, file_path: str, chat_id: int, filename: str = None, reply_no: int = None, quote_range: str = None) -> File:
 
-        res = self._upload_file(file_path=file_path, chat_id=chat_id, filename=filename, reply_no=reply_no, quote_range=quote_range)
-        return File(self, **res.get('data', {}))
+        res, extra = self._upload_file(file_path=file_path, chat_id=chat_id, filename=filename, reply_no=reply_no, quote_range=quote_range)
+        return File(self, guid=res['guid'], mime_type=extra['type'], **extra)
 
     def upload_file(self, file_path: str, chat_id: int, filename: str = None, is_avatar=False) -> File:
-        res = self._upload_file(file_path=file_path, chat_id=chat_id, filename=filename)
-        return File(self, **res.get('data', {}))
+        res, extra = self._upload_file(file_path=file_path, chat_id=chat_id, filename=filename)
+        return File(self, guid=res['guid'], mime_type=extra['type'], **extra)
 
     def old_upload_file(self, file_path: str, chat_id: int, filename: str = None, is_avatar=False) -> File:
+        # not work
         perm_url = '/file/upload'
         file_info = self._get_file_info(file_path, filename, guess_type=True)
         perm_resp = self.api_post(perm_url, {
