@@ -10,17 +10,16 @@ ATTR_FORMATTERS: Dict[str, Callable[[dict, str], Any]] = {}
 
 class File:
     """
+    From /upload
     {
-     "data":
-      {"path": "4faf5a45c5ba447ab7004b30181dd4c1/image.jpg",
-       "name": "image.jpg",
-       "source": "upload",
-       "size": 2845000,
-       "guid": "4faf5a45c5ba447ab7004b30181dd4c1",
-       "up_time": "2017-08-23 12:11:54,161837",
-       "id": 435,
-       "type": "image/jpeg"},
-     "status": "success"
+        "guid": "4faf5a45c5ba447ab7004b30181dd4c1"
+    }
+    From post.meta.file
+    {
+        "guid": "720ef462f19d43259f4af9fc2b75cdcf",
+        "name": "image.png",
+        "mime_type": "image/png",
+        "size": 41935
     }
     """
     _client: 'Pararamio'
