@@ -13,6 +13,7 @@ from pararamio.deferred_post import DeferredPost
 from pararamio.exceptions import PararamioException, PararamioValidationException
 from pararamio.post import Post
 from pararamio.user import User
+from pararamio.activity import ActivityAction
 from tests.integrations._base import BasePararamioTest
 
 
@@ -123,7 +124,7 @@ class PararamioClientTest(BasePararamioTest):
         self.assertTrue(u.unique_name)
 
     def test_012_chat_load(self, ):
-        u = self.client.search_user('tamtambottester2@gmail.com')[0]
+        u = self.client.search_user(self.recipient_email)[0]
         chat = u.get_pm_thread()
         chat.load()
         pc = chat.posts_count
@@ -188,7 +189,7 @@ class PararamioClientTest(BasePararamioTest):
         post = [p for p in posts if p.text == text]
         self.assertTrue(bool(post), 'Post is empty')
         self.assertTrue(post[0].text == text, 'text is not match')
-        self.assertTrue(post[0].time_sending == (time_sending - timedelta(microseconds=time_sending.microsecond)))
+        self.assertTrue(int(post[0].time_sending.timestamp()) == int(time_sending.timestamp()))
         post[0].delete()
 
     def test_019_posts_tree(self):
@@ -200,12 +201,12 @@ class PararamioClientTest(BasePararamioTest):
         ]):
             with patch.object(chat, '_lazy_posts_loader', return_value=iter([
                 Post(chat, post_no=96, text='post no 96', reply_no=None),
-                Post(chat, post_no=97, text='post no 97', reply_no=96),
-                Post(chat, post_no=98, text='post no 98', reply_no=97),
+                Post(chat, post_no=97, text='post no 97', reply_no=None),
+                Post(chat, post_no=98, text='post no 98', reply_no=96),
                 Post(chat, post_no=99, text='post no 99', reply_no=96),
             ])):
                 post = Post(chat, post_no=100, text='post no 100', reply_no=99, meta={})
-                self.assertListEqual([96, 97, 98, 99, 100], list(post.get_tree().keys()))
+                self.assertListEqual([96, 98, 99, 100], list(post.get_tree().keys()))
         many_fake_posts = [
             Post(chat, post_no=1, text='post no 1', reply_no=None),
             *[Post(chat, text=f'post no {i}', post_no=i, reply_no=i - 1) for i in range(2, 2000)],
@@ -215,15 +216,13 @@ class PararamioClientTest(BasePararamioTest):
         def _load_posts_side_effect(start, end):
             return iter(many_fake_posts[start: end])
 
-        import logging
-
-        logging.basicConfig(level=logging.DEBUG)
         with patch.object(Post, 'rerere', return_value=[many_fake_posts[0], *many_fake_posts[1000:]]):
             chat._load_posts = MagicMock(side_effect=_load_posts_side_effect)
-            self.assertListEqual([many_fake_posts[0].post_no, *[p.post_no for p in many_fake_posts[1000:]]], list(many_fake_posts[-1].get_tree().keys()))
+            posts = list(many_fake_posts[-1].get_tree().keys())
+            self.assertListEqual([many_fake_posts[0].post_no, *[p.post_no for p in many_fake_posts[1000:]]], posts)
 
         with patch.object(Post, 'rerere', return_value=[]):
-            chat._load_posts = MagicMock(side_effect=lambda a,b: [])
+            chat._load_posts = MagicMock(side_effect=lambda a, b: [])
             self.assertListEqual([2000], list(many_fake_posts[-1].get_tree().keys()))
 
     def test_020_send_and_delete_message_by_email(self):
@@ -250,6 +249,20 @@ class PararamioClientTest(BasePararamioTest):
         self.assertTrue(post.text == text)
         self.assertIsNotNone(post.delete())
 
+    def test_022_activity_loading(self):
+        u1 = self.client.search_user(self.client.profile.get('email'))[0]
+        u2 = self.client.search_user(self.recipient_email)[0]
+        post = u2.post('test')
+        time.sleep(10)
+        start = datetime.utcnow().replace(tzinfo=timezone.utc) - timedelta(minutes=5)
+        end = datetime.utcnow().replace(tzinfo=timezone.utc)
+        self.assertTrue(bool(u1.get_activity(start, end)), 'all activity list is empty')
+        acts = u1.get_activity(start, end, [ActivityAction.POST])
+        self.assertTrue(bool(acts), 'post activity list is empty')
+        for act in acts:
+            self.assertTrue(act.action == ActivityAction.POST, 'post activity list contains another action')
+        self.assertTrue(int(post.time_created.timestamp()) == int(acts[-1].time.timestamp()), 'last post action time not match last post time')
+
     @classmethod
     def tearDownClass(cls):
         if os.path.exists('test.cookie'):
